import requests
import json

host = "https://piopiy.telecmi.com/v1/make_call"


class Voice:

    def __init__(self, appid, secret):
        self.appid = appid
        self.secret = secret

    def make(self, to, piopiy_no, answer_url):

        if isinstance(to, int) and isinstance(piopiy_no, int) and isinstance(answer_url, str):
            data = {'from': piopiy_no, 'appid': self.appid,
                    'secret': self.secret, 'to': to, 'answer_url': answer_url}
            headers = {'content-type': 'application/json'}
            return requests.post(host, data=json.dumps(data), headers=headers).text
        else:

            raise NameError('invalid argument type to make call')



from voice import Voice


class RestClient:

    def __init__(self, appid, secret):
        self.appid = appid
        self.secret = secret

    def make(self, to, piopiy_no, answer_url):
        return Voice(self.appid, self.secret).make(to, piopiy_no, answer_url)



import io
import os

from setuptools import setup, find_packages


with io.open(
    os.path.join(os.path.dirname(__file__), "README.md"), encoding="utf-8"
) as f:
    long_description = f.read()

setup(
    name="piopiy",
    version="0.5.0",
    description="PIOPIY REST API for Python",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/telecmi/piopiy_python",
    author="PIOPIY",
    author_email="support@telecmi.com",
    license="MIT",
    packages=find_packages(where="src"),
    package_dir={"": "src"},
    platforms=["any"],
    install_requires=["requests>=2.4.2"],
    python_requires=">=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*",
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
    ],
)
